@@ -1,3 +1,5 @@
+import json
+
 from jsonview.decorators import json_view
 from django.conf import settings
 from django.utils.http import is_safe_url
@@ -12,7 +14,27 @@ from django.template import RequestContext
 from django.shortcuts import render_to_response
 from django.http import Http404
 from django.contrib.auth import get_user_model
-from auth_pack.forms import UserRegistrationForm, UserAuthenticationForm
+from auth_pack.forms import UserRegistrationForm, UserAuthenticationForm, UserChangePasswordForm
+from django.http import HttpResponse
+from django.views.generic.edit import FormView
+
+
+class AjaxFormView(FormView):
+    def render_to_json_response(self, context, **response_kwargs):
+        data = json.dumps(context)
+        response_kwargs['content_type'] = 'application/json'
+        return HttpResponse(data, **response_kwargs)
+
+    def form_invalid(self, form):
+        form_html = render_crispy_form(form)
+        return self.render_to_json_response(
+            {'success': False, 'form_html': form_html},
+        )
+
+    def form_valid(self, form):
+        return self.render_to_json_response(
+            {'success': True, 'redirect_to': self.get_success_url()},
+        )
 
 
 @sensitive_post_parameters()
@@ -78,3 +100,19 @@ def activate(request, template_name='accounts/activate.html',
     return render_to_response(template_name,
                               kwargs,
                               context_instance=context)
+
+
+class ChangePasswordView(AjaxFormView):
+    template_name = 'accounts/change_password.html'
+    form_class = UserChangePasswordForm
+    success_url = '/accounts/profile/'
+
+    def form_valid(self, form):
+        form.user_cache.set_password(form.cleaned_data['new_password2'])
+        form.user_cache.save()
+        return super(ChangePasswordView, self).form_valid(form)
+
+    def get_initial(self):
+        initial = super(ChangePasswordView, self).get_initial()
+        initial['email'] = self.request.user.email
+        return initial
